@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -75,7 +75,7 @@ nacore_avl_tree_new(nacore_cmp_cb cmp_cb, nacore_get_size_cb gs_cb);
 /*
    Function: nacore_avl_tree_free()
 
-   Destroies a tree and all its elements.
+   Destroys a tree and all its elements.
 
    If the tree is auto-allocating, value copies inside each element are
    destroied too.
@@ -148,7 +148,7 @@ nacore_avl_tree_get_last(nacore_avl_tree tree);
 /*
    Function: nacore_avl_tree_insert()
 
-   Inserts a new element into a tree.
+   Creates a new tree element and inserts it into a tree.
 
    Parameters:
 
@@ -162,6 +162,10 @@ nacore_avl_tree_get_last(nacore_avl_tree tree);
    Returns:
 
      New tree element containing value or NULL if there was not enough memory.
+
+   See also:
+
+     <nacore_avl_tree_elem_insert()>.
  */
 _NACORE_DEF nacore_avl_tree_elem
 nacore_avl_tree_insert(nacore_avl_tree tree, void *cmp_opaque, void *gs_opaque,
@@ -170,7 +174,8 @@ nacore_avl_tree_insert(nacore_avl_tree tree, void *cmp_opaque, void *gs_opaque,
 /*
    Function: nacore_avl_tree_pop()
 
-   Removes an element from a tree and returns the value it contains.
+   Removes an element from a tree, destroys it and returns the value it
+   contains.
 
    Once this function is called, referring to elem will cause undefined
    behavior.
@@ -184,6 +189,10 @@ nacore_avl_tree_insert(nacore_avl_tree tree, void *cmp_opaque, void *gs_opaque,
 
      The value contained in the element being removed. If the tree is
      auto-allocating the caller is in charge of free()ing the value.
+
+   See also:
+
+     <nacore_avl_tree_elem_pop()>.
  */
 _NACORE_DEF void *
 nacore_avl_tree_pop(nacore_avl_tree tree, nacore_avl_tree_elem elem);
@@ -418,15 +427,92 @@ nacore_avl_tree_dump(nacore_avl_tree tree, nacore_to_string_cb to_string_cb,
 		     void *to_string_opaque);
 
 /*
-   Function: nacore_avl_tree_elem_get_value()
+   Function: nacore_avl_tree_elem_new()
 
-   Gets the value contained in a tree element.
+   Creates a new tree element without adding it to a tree.
+
+   Parameters:
+
+     value	- The value to be contained in the element.
+
+   Returns:
+
+     New tree element containing value or NULL if there was not enough memory.
+ */
+_NACORE_DEF nacore_avl_tree_elem
+nacore_avl_tree_elem_new(void *value);
+
+/*
+   Function: nacore_avl_tree_elem_free()
+
+   Destroys a tree element.
+
+   Once this function is called, referring to elem will cause undefined
+   behavior.
+
+   Only to be used when the element is not part of a tree.
+
+   Parameters:
+
+     elem	- Tree element.
+ */
+_NACORE_DEF void
+nacore_avl_tree_elem_free(nacore_avl_tree_elem elem);
+
+/*
+   Function: nacore_avl_tree_elem_insert()
+
+   Inserts a tree element into a tree.
+
+   Only to be used when the element to be insterted is not part of a tree.
+
+   Beware of auto-allocating trees...
+
+   Parameters:
+
+     tree		- AVL tree.
+     elem		- Tree element.
+     cmp_opaque		- Extra opaque data to be passed to the value comparison
+			  callback or NULL.
+
+   See also:
+
+     <nacore_avl_tree_insert()>.
+ */
+_NACORE_DEF void
+nacore_avl_tree_elem_insert(nacore_avl_tree tree, nacore_avl_tree_elem elem,
+			    void *cmp_opaque);
+
+/*
+   Function: nacore_avl_tree_elem_pop()
+
+   Removes an element from a tree without destroying it.
 
    Parameters:
 
      tree	- AVL tree.
      elem	- Tree element.
 
+   See also:
+
+     <nacore_avl_tree_pop()>.
+ */
+_NACORE_DEF void
+nacore_avl_tree_elem_pop(nacore_avl_tree tree, nacore_avl_tree_elem elem);
+
+/*
+   Function: nacore_avl_tree_elem_get_value()
+
+   Gets the value contained in a tree element.
+
+   The tree parameter is currently unused. It is however good if you set it to
+   NULL only when elem is not part of a tree.
+
+   Parameters:
+
+     tree	- AVL tree the element belongs to or NULL.
+     elem	- Tree element.
+
    Returns:
 
      The value contained in elem.
@@ -440,16 +526,17 @@ nacore_avl_tree_elem_get_value(nacore_avl_tree tree, nacore_avl_tree_elem elem);
    Sets the value contained in a tree element and rearranges the tree to keep
    the sorting if needed.
 
-   If the tree is auto-allocating, first the old value is free()d, then a copy
-   of the new value is put into the element.
+   If the element is not part of a tree set tree as NULL, in which case the
+   function shall behave as if the element is part of a normal tree.
 
-   In any case, before potentially being destroyed, the element value is passed
-   to the free_cb callback, if one is given, as well as the specified extra
-   data.
+   If the tree is auto-allocating, first the old value is free()d, then a copy
+   of the new value is put into the element. Before potentially being destroyed,
+   the element value is passed to the free_cb callback, if one is given, as well
+   as the specified extra data.
 
    Parameters:
 
-     tree		- AVL tree the element belongs to.
+     tree		- AVL tree the element belongs to or NULL.
      elem		- Tree element.
      free_cb		- Callback called to destroy element value or NULL.
      free_opaque	- Extra opaque data to be passed to free_cb or NULL.
