@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -10,7 +10,7 @@
 /*
    Title: NASPRO core
 
-   *Version*: 0.3.0, *API*: 4.0.0.
+   *Version*: 0.4.0, *API*: 5.0.0.
 
    About:
 
@@ -22,13 +22,17 @@
      a small collection of abstract data types and provides a couple of useful
      APIs to help with software development in general.
 
+     The code is released under the <LGPL 2.1 at
+     http://www.gnu.org/licenses/lgpl-2.1.html>.
+
    Supported platforms/compilers:
 
      It is written in C99 and should work on all POSIX-1.2008-compliant
      platforms, assuming that malloc() and free() are thread-safe and errno is
      thread-local.
 
-     It does also work on Windows XP and later, 32 and 64 bit versions.
+     It should also work (but it's not yet "officially supported") on Windows XP
+     and later, 32 and 64 bit versions.
 
      It has only been built and tested using the <GCC at http://gcc.gnu.org/>
      compiler, for which it has special support and whose version is supposed to
@@ -54,7 +58,7 @@
 
      * An environment capable of running Autotools-based build systems;
      * (optional) <GNU Autoconf at http://www.gnu.org/software/autoconf/> >=
-       2.61, <GNU Automake at http://www.gnu.org/software/automake/> and
+       2.68, <GNU Automake at http://www.gnu.org/software/automake/> and
        <GNU Libtool at http://www.gnu.org/software/libtool/> to regenerate the
        build system;
      * (optional) <Natural Docs at http://www.naturaldocs.org/> >= 1.5 to
@@ -64,7 +68,7 @@
 
       Just include <NASPRO/core/lib.h> in your source files and use the
       <pkg-config at http://pkg-config.freedesktop.org/> tool to retrieve
-      compiler and linker flags (package name: nacore-4).
+      compiler and linker flags (package name: nacore-5).
  */
 
 #ifndef _NASPRO_CORE_LIB_H
@@ -76,14 +80,14 @@
 #include <errno.h>
 #include <locale.h>
 
-/*#ifdef _WIN32
+#ifdef _WIN32
 # include <windows.h>
 #else
-# include <pthread.h>*/
+# include <pthread.h>
 # ifdef __APPLE__
 #  include <xlocale.h>
 # endif
-/*#endif*/
+#endif
 
 #include <NASPRO/core/cc.h>
 
@@ -98,11 +102,12 @@
 #include <NASPRO/core/avl.h>
 #include <NASPRO/core/string.h>
 #include <NASPRO/core/msg.h>
-/* #include <NASPRO/core/thread.h>
-#include <NASPRO/core/mutex.h> */
 #include <NASPRO/core/env.h>
 #include <NASPRO/core/locale.h>
 #include <NASPRO/core/fs.h>
 #include <NASPRO/core/dl.h>
+#include <NASPRO/core/thread.h>
+#include <NASPRO/core/mutex.h>
+#include <NASPRO/core/sem.h>
 
 #endif
