@@ -74,7 +74,7 @@ nacore_list_new(nacore_get_size_cb gs_cb);
 /*
    Function: nacore_list_free()
 
-   Destroies a list and all its elements.
+   Destroys a list and all its elements.
 
    If the list is auto-allocating, value copies inside each element are
    destroied too.
@@ -147,7 +147,7 @@ nacore_list_get_tail(nacore_list list);
 /*
    Function: nacore_list_prepend()
 
-   Prepends a new element to a list.
+   Creates a new list element and prepends it to a list.
 
    Parameters:
 
@@ -159,6 +159,10 @@ nacore_list_get_tail(nacore_list list);
    Returns:
 
      New list element containing value or NULL if there was not enough memory.
+
+   See also:
+
+     <nacore_list_elem_prepend()>.
  */
 _NACORE_DEF nacore_list_elem
 nacore_list_prepend(nacore_list list, void *gs_opaque, void *value);
@@ -166,7 +170,7 @@ nacore_list_prepend(nacore_list list, void *gs_opaque, void *value);
 /*
    Function: nacore_list_append()
 
-   Appends a new element to a list.
+   Creates a new list element and appends it to a list.
 
    Parameters:
 
@@ -178,6 +182,10 @@ nacore_list_prepend(nacore_list list, void *gs_opaque, void *value);
    Returns:
 
      New list element containing value or NULL if there was not enough memory.
+
+   See also:
+
+     <nacore_list_elem_append()>.
  */
 _NACORE_DEF nacore_list_elem
 nacore_list_append(nacore_list list, void *gs_opaque, void *value);
@@ -185,7 +193,7 @@ nacore_list_append(nacore_list list, void *gs_opaque, void *value);
 /*
    Function: nacore_list_insert_before()
 
-   Inserts a new element before another given element in a list.
+   Creates a new list element and inserts it before another element in a list.
 
    Parameters:
 
@@ -199,6 +207,10 @@ nacore_list_append(nacore_list list, void *gs_opaque, void *value);
    Returns:
 
      New list element containing value or NULL if there was not enough memory.
+
+   See also:
+
+     <nacore_list_elem_insert_before()>.
  */
 _NACORE_DEF nacore_list_elem
 nacore_list_insert_before(nacore_list list, nacore_list_elem elem,
@@ -207,7 +219,7 @@ nacore_list_insert_before(nacore_list list, nacore_list_elem elem,
 /*
    Function: nacore_list_insert_after()
 
-   Inserts a new element after another given element in a list.
+   Creates a new list element and inserts it after another element in a list.
 
    Parameters:
 
@@ -221,6 +233,10 @@ nacore_list_insert_before(nacore_list list, nacore_list_elem elem,
    Returns:
 
      New list element containing value or NULL if there was not enough memory.
+
+   See also:
+
+     <nacore_list_elem_insert_after()>.
  */
 _NACORE_DEF nacore_list_elem
 nacore_list_insert_after(nacore_list list, nacore_list_elem elem,
@@ -265,7 +281,8 @@ nacore_list_move_after(nacore_list list, nacore_list_elem dest,
 /*
    Function: nacore_list_pop()
 
-   Removes an element from a list and returns the value it contains.
+   Removes an element from a list, destroys it and returns the value it
+   contains.
 
    Once this function is called, referring to elem will cause undefined
    behavior.
@@ -279,6 +296,10 @@ nacore_list_move_after(nacore_list list, nacore_list_elem dest,
 
      The value contained in the element being removed. If the list is
      auto-allocating the caller is in charge of free()ing the value.
+
+   See also:
+
+     <nacore_list_elem_pop()>.
  */
 _NACORE_DEF void *
 nacore_list_pop(nacore_list list, nacore_list_elem elem);
@@ -489,14 +510,153 @@ _NACORE_DEF void
 nacore_list_dump(nacore_list list, nacore_to_string_cb to_string_cb,
 		 void *to_string_opaque);
 
+/*
+   Function: nacore_list_elem_new()
+
+   Creates a new list element without adding it to a list.
+
+   Parameters:
+
+     value	- The value to be contained in the element.
+
+   Returns:
+
+     New list element containing value or NULL if there was not enough memory.
+ */
+_NACORE_DEF nacore_list_elem
+nacore_list_elem_new(void *value);
+
+/*
+   Function: nacore_list_elem_free()
+
+   Destroys a list element.
+
+   Once this function is called, referring to elem will cause undefined
+   behavior.
+
+   Only to be used when the element is not part of a list.
+
+   Parameters:
+
+     elem	- List element.
+ */
+_NACORE_DEF void
+nacore_list_elem_free(nacore_list_elem elem);
+
+/*
+   Function: nacore_list_elem_prepend()
+
+   Prepends a list element to a list.
+
+   Only to be used when the element is not part of a list.
+
+   Beware of auto-allocating lists...
+
+   Parameters:
+
+     list	- Doubly-linked list.
+     elem	- List element.
+
+   See also:
+
+     <nacore_list_prepend()>.
+ */
+_NACORE_DEF void
+nacore_list_elem_prepend(nacore_list list, nacore_list_elem elem);
+
+/*
+   Function: nacore_list_elem_append()
+
+   Appends a list element to a list.
+
+   Only to be used when the element is not part of a list.
+
+   Beware of auto-allocating lists...
+
+   Parameters:
+
+     list	- Doubly-linked list.
+     elem	- List element.
+
+   See also:
+
+     <nacore_list_append()>.
+ */
+_NACORE_DEF void
+nacore_list_elem_append(nacore_list list, nacore_list_elem elem);
+
+/*
+   Function: nacore_list_elem_insert_before()
+
+   Inserts a list element before another element in a list.
+
+   Only to be used when the element to be inserted is not part of a list.
+
+   Beware of auto-allocating lists...
+
+   Parameters:
+
+     list	- Doubly-linked list.
+     elem	- List element.
+
+   See also:
+
+     <nacore_list_insert_before()>.
+ */
+_NACORE_DEF void
+nacore_list_elem_insert_before(nacore_list list, nacore_list_elem elem,
+			       nacore_list_elem before);
+
+/*
+   Function: nacore_list_elem_insert_after()
+
+   Inserts a list element after another element in a list.
+
+   Only to be used when the element to be inserted is not part of a list.
+
+   Beware of auto-allocating lists...
+
+   Parameters:
+
+     list	- Doubly-linked list.
+     elem	- List element.
+
+   See also:
+
+     <nacore_list_insert_after()>.
+ */
+_NACORE_DEF void
+nacore_list_elem_insert_after(nacore_list list, nacore_list_elem elem,
+			      nacore_list_elem after);
+
+/*
+   Function: nacore_list_elem_pop()
+
+   Removes an element from a list without destroying it.
+
+   Parameters:
+
+     list	- Doubly-linked list.
+     elem	- List element.
+
+   See also:
+
+     <nacore_list_pop()>.
+ */
+_NACORE_DEF void
+nacore_list_elem_pop(nacore_list list, nacore_list_elem elem);
+
 /*
    Function: nacore_list_elem_get_value()
 
    Gets the value contained in a list element.
 
+   The list parameter is currently unused. It is however good if you set it to
+   NULL only when elem is not part of a list.
+
    Parameters:
 
-     list	- Doubly-linked list the element belongs to.
+     list	- Doubly-linked list the element belongs to or NULL.
      elem	- List element.
 
    Returns:
@@ -511,16 +671,17 @@ nacore_list_elem_get_value(nacore_list list, nacore_list_elem elem);
 
    Sets the value contained in a list element.
 
-   If the list is auto-allocating, first the old value is free()d, then a copy
-   of the new value is put into the element.
+   If the element is not part of a list set list as NULL, in which case this
+   function shall behave as if the element is part of a normal list.
 
-   In any case, before potentially being destroyed, the element value is passed
-   to the free_cb callback, if one is given, as well as the specified extra
-   data.
+   If the list is auto-allocating, first the old value is free()d, then a copy
+   of the new value is put into the element. Before potentially being destroyed,
+   the element value is passed to the free_cb callback, if one is given, as well
+   as the specified extra data.
 
    Parameters:
 
-     list		- Doubly-linked list the element belongs to.
+     list		- Doubly-linked list the element belongs to or NULL.
      elem		- List element.
      free_cb		- Callback called to destroy element value or NULL.
      free_opaque	- Extra opaque data to be passed to free_cb or NULL.
@@ -550,7 +711,7 @@ nacore_list_elem_set_value(nacore_list list, nacore_list_elem elem,
 
    Returns:
 
-     Previous element w.r.t. the given element or NULL if the is none (i.e.,
+     Previous element w.r.t. the given element or NULL if there is none (i.e.,
      elem is the head of the list).
  */
 _NACORE_DEF nacore_list_elem
