@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -32,11 +32,11 @@
 
    * The caller function may create a status message regarding the operations of
      a called function, not the other way round (e.g., main() creates a status
-     message saying "Reading files x", then it calls read_file()).
+     message saying "Reading file x", then it calls read_file()).
    * The result of a status message shall be set by the caller function and
      never by the called function.
-   * When displaying, the last received text message with the highet severity is
-     the main message to be displayed.
+   * When displaying, the last received text message with the highest severity
+     is the main message to be displayed.
    * The text of a message is meant to be plain text, not HTML or similar.
    * Messages referring to a certain line/column should be formatted like
      "line:column: message".
@@ -153,8 +153,6 @@ typedef void
 
    Creates a new message box.
 
-   This function is not reentrant.
-
    Parameters:
 
      opaque	- Extra opaque data to be associated to the message box or NULL.
@@ -170,7 +168,7 @@ nacore_msg_box_new(void *opaque);
 /*
    Function: nacore_msg_box_free()
 
-   Destroies a message box.
+   Destroys a message box.
 
    It is not thread-safe to concurrently use this function while operating on
    the message box and/or the messages directly or indirectly belonging to it.
@@ -178,6 +176,9 @@ nacore_msg_box_new(void *opaque);
    Furthermore it should only be used when all the status messages belonging to
    it have been already destroied.
 
+   Once this function function is called, referring to msg_box will cause
+   undefined behavior.
+
    Parameters:
 
      msg_box	- Message context representing the message box.
@@ -250,7 +251,7 @@ nacore_msg_status_begin(nacore_msg_context context, void *opaque,
    Function: nacore_msg_status_end()
 
    Possibly reports the result of the operation described by a status message to
-   the status message end callback and destroies such status message.
+   the status message end callback and destroys such status message.
 
    In order to simplify the usage of the API, status_msg can be NULL, in which
    case the function does nothing.
