@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -72,39 +72,39 @@ _NACORE_DEF size_t
 nacore_char_utf8_decode(const char *utf8c, uint32_t *cp);
 
 /*
-   Function: nacore_char_utf16le_encode()
+   Function: nacore_char_utf16_encode()
 
-   Encodes a Unicode code point into an UTF-16LE character.
+   Encodes a Unicode code point into an UTF-16 character.
 
-   If utf16lec is NULL, it does only calculate the length in bytes of the
-   UTF-16LE character corresponding to the given code point.
+   If utf16c is NULL, it does only calculate the length in bytes of the UTF-16
+   character corresponding to the given code point.
 
    Parameters:
 
-     utf16lec	- Pointer to a large enough buffer to contain the resulting
-		  UTF-16LE character (worst case: 4 bytes wide) or NULL.
+     utf16c	- Pointer to a large enough buffer to contain the resulting
+		  UTF-16 character (worst case: 4 bytes wide) or NULL.
      cp		- Code point.
 
    Returns:
 
-     Length in bytes of the resulting UTF-16LE character or 0 if cp is outside
-     of the valid value range (0 to 0x10ffff, except 0xd800 to 0xdfff, 0xfeff
-     and 0xfffe).
+     Length in bytes of the resulting UTF-16 character or 0 if cp is outside of
+     the valid value range (0 to 0x10ffff, except 0xd800 to 0xdfff, 0xfeff and
+     0xfffe).
  */
 _NACORE_DEF size_t
-nacore_char_utf16le_encode(char *utf16lec, uint32_t cp);
+nacore_char_utf16_encode(uint16_t *utf16c, uint32_t cp);
 
 /*
-   Function: nacore_char_utf16le_decode()
+   Function: nacore_char_utf16_decode()
 
-   Decodes the Unicode code point associated to an UTF-16LE character.
+   Decodes the Unicode code point associated to an UTF-16 character.
 
    If cp is not NULL and the encoding is valid, the code point is stored into
    *cp.
 
    Parameters:
 
-     utf16lec	- Pointer to the buffer containing the UTF-16LE character to be
+     utf16c	- Pointer to the buffer containing the UTF-16 character to be
 		  decoded.
      cp		- Pointer to the memory location where to put the code point
 		  value or NULL.
@@ -115,13 +115,13 @@ nacore_char_utf16le_encode(char *utf16lec, uint32_t cp);
      in which case nothing is written in *cp.
  */
 _NACORE_DEF size_t
-nacore_char_utf16le_decode(const char *utf16lec, uint32_t *cp);
+nacore_char_utf16_decode(const uint16_t *utf16c, uint32_t *cp);
 
 /*
-   Function: nacore_string_utf8_to_utf16le_len()
+   Function: nacore_string_utf8_to_utf16_len()
 
-   Calculates the number of bytes needed to store the UTF-16LE representation of
-   a UTF-8 encoded string, excluding the terminating null character.
+   Calculates the number of bytes needed to store the UTF-16 representation of a
+   UTF-8 encoded string, excluding the terminating null character.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
@@ -132,17 +132,17 @@ nacore_char_utf16le_decode(const char *utf16lec, uint32_t *cp);
 
    Returns:
 
-     Number of bytes needed to store the UTF-16LE representation of str_utf8,
+     Number of bytes needed to store the UTF-16 representation of str_utf8,
      excluding the terminating null character.
  */
 _NACORE_DEF size_t
-nacore_string_utf8_to_utf16le_len(const char *str_utf8);
+nacore_string_utf8_to_utf16_len(const char *str_utf8);
 
 /*
-   Function: nacore_string_utf8_to_utf16le()
+   Function: nacore_string_utf8_to_utf16()
 
-   Converts a UTF-8 encoded string to UTF-16LE into a previously allocated
-   buffer, including the terminating null character.
+   Converts a UTF-8 encoded string to UTF-16 into a previously allocated buffer,
+   including the terminating null character.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
@@ -153,12 +153,12 @@ nacore_string_utf8_to_utf16le_len(const char *str_utf8);
      str_utf8	- UTF-8 encoded string to be converted.
  */
 _NACORE_DEF void
-nacore_string_utf8_to_utf16le(char *buf, const char *str_utf8);
+nacore_string_utf8_to_utf16(uint16_t *buf, const char *str_utf8);
 
 /*
-   Function: nacore_string_utf8_to_utf16le_a()
+   Function: nacore_string_utf8_to_utf16_a()
 
-   Converts a UTF-8 encoded string to UTF-16LE, allocating the output string.
+   Converts a UTF-8 encoded string to UTF-16, allocating the output string.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
@@ -169,61 +169,61 @@ nacore_string_utf8_to_utf16le(char *buf, const char *str_utf8);
 
    Returns:
 
-     A malloc()-allocated, UTF-16LE encoded string or NULL if there was not
-     enough memory. The caller is in charge of free()ing such string.
+     A malloc()-allocated, UTF-16 encoded string or NULL if there was not enough
+     memory. The caller is in charge of free()ing such string.
  */
-_NACORE_DEF char *
-nacore_string_utf8_to_utf16le_a(const char *str_utf8);
+_NACORE_DEF uint16_t *
+nacore_string_utf8_to_utf16_a(const char *str_utf8);
 
 /*
-   Function: nacore_string_utf16le_to_utf8_len()
+   Function: nacore_string_utf16_to_utf8_len()
 
    Calculates the number of bytes needed to store the UTF-8 representation of a
-   a UTF-16LE encoded string, excluding the terminating null character.
+   UTF-16 encoded string, excluding the terminating null character.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
 
    Parameters:
 
-     str_utf16le	- UTF-16LE encoded string.
+     str_utf16	- UTF-16 encoded string.
 
    Returns:
 
-     Number of bytes needed to store the UTF-8 representation of str_utf16le,
+     Number of bytes needed to store the UTF-8 representation of str_utf16,
      excluding the terminating null character.
  */
 _NACORE_DEF size_t
-nacore_string_utf16le_to_utf8_len(const char *str_utf16le);
+nacore_string_utf16_to_utf8_len(const uint16_t *str_utf16);
 
 /*
-   Function: nacore_string_utf16le_to_utf8()
+   Function: nacore_string_utf16_to_utf8()
 
-   Converts a UTF-16LE encoded string to UTF-8 into a previously allocated
-   buffer, including the terminating null character.
+   Converts a UTF-16 encoded string to UTF-8 into a previously allocated buffer,
+   including the terminating null character.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
 
    Parameters:
 
-     buf		- Output buffer.
-     str_utf16le	- UTF-16LE encoded string to be converted.
+     buf	- Output buffer.
+     str_utf16	- UTF-16 encoded string to be converted.
  */
 _NACORE_DEF void
-nacore_string_utf16le_to_utf8(char *buf, const char *str_utf16le);
+nacore_string_utf16_to_utf8(char *buf, const uint16_t *str_utf16);
 
 /*
-   Function: nacore_string_utf16le_to_utf8_a()
+   Function: nacore_string_utf16_to_utf8_a()
 
-   Converts a UTF-16LE encoded string to UTF-8, allocating the output string.
+   Converts a UTF-16 encoded string to UTF-8, allocating the output string.
 
    It tries to skip badly encoded data, yet it's actually just guessing, hence
    try to avoid relying on this behavior.
 
    Parameters:
 
-     str_utf16le	- UTF-16LE encoded string to be converted.
+     str_utf16	- UTF-16 encoded string to be converted.
 
    Returns:
 
@@ -231,7 +231,7 @@ nacore_string_utf16le_to_utf8(char *buf, const char *str_utf16le);
      memory. The caller is in charge of free()ing such string.
  */
 _NACORE_DEF char *
-nacore_string_utf16le_to_utf8_a(const char *str_utf16le);
+nacore_string_utf16_to_utf8_a(const uint16_t *str_utf16);
 
 /*
    Function: nacore_string_get_size()
