@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -304,38 +304,6 @@ adjust_up(nacore_avl_tree tree, nacore_avl_tree_elem elem)
 	  }
 }
 
-static void
-insert(nacore_avl_tree tree, nacore_avl_tree_elem elem, void *cmp_opaque)
-{
-	int side;
-
-	elem->left   = NULL;
-	elem->right  = NULL;
-	elem->height = 1;
-
-	elem->parent = lookup(tree, elem->value, &side, cmp_opaque);
-
-	if (elem->parent == NULL)
-	  {
-		tree->root = elem;
-		tree->count++;
-		return;
-	  }
-
-	if (side == 0)
-		while (elem->parent->left != NULL)
-			elem->parent = elem->parent->left;
-
-	if (side <= 0)
-		elem->parent->left = elem;
-	else
-		elem->parent->right = elem;
-
-	adjust_up(tree, elem);
-
-	tree->count++;
-}
-
 _NACORE_DEF nacore_avl_tree_elem
 nacore_avl_tree_insert(nacore_avl_tree tree, void *cmp_opaque, void *gs_opaque,
 		       void *value)
@@ -361,108 +329,17 @@ nacore_avl_tree_insert(nacore_avl_tree tree, void *cmp_opaque, void *gs_opaque,
 	else
 		ret->value = value;
 
-	insert(tree, ret, cmp_opaque);
+	nacore_avl_tree_elem_insert(tree, ret, cmp_opaque);
 
 	return ret;
 }
 
-static void
-pop(nacore_avl_tree tree, nacore_avl_tree_elem elem)
-{
-	nacore_avl_tree_elem p, e;
-
-	if ((elem->left == NULL) && (elem->right == NULL))
-	  {
-		if (elem->parent == NULL)
-		  {
-			tree->root = NULL;
-			tree->count--;
-			return;
-		  }
-
-		e = elem->parent;
-
-		if (e->left == elem)
-			e->left = NULL;
-		else
-			e->right = NULL;
-	  }
-	else if ((elem->left != NULL) && (elem->right == NULL))
-	  {
-		if (elem->parent == NULL)
-		  {
-			tree->root = elem->left;
-			elem->left->parent = NULL;
-			tree->count--;
-			return;
-		  }
-
-		e = elem->parent;
-
-		elem->left->parent = e;
-		if (e->left == elem)
-			e->left = elem->left;
-		else
-			e->right = elem->left;
-	  }
-	else if ((elem->left == NULL) && (elem->right != NULL))
-	  {
-		if (elem->parent == NULL)
-		  {
-			tree->root = elem->right;
-			elem->right->parent = NULL;
-			tree->count--;
-			return;
-		  }
-
-		e = elem->parent;
-
-		elem->right->parent = e;
-		if (e->left == elem)
-			e->left = elem->right;
-		else
-			e->right = elem->right;
-	  }
-	else
-	  {
-		for (e = elem->right; e->left != NULL; e = e->left) ;
-		p = e->parent;
-
-		e->left = elem->left;
-		e->left->parent = e;
-		if (elem->right != e)
-		  {
-			p->left = e->right;
-			e->right = elem->right;
-			e->right->parent = e;
-		  }
-		else
-			p = e;
-		e->parent = elem->parent;
-		if (e->parent != NULL)
-		  {
-			if (e->parent->left == elem)
-				e->parent->left = e;
-			else
-				e->parent->right = e;
-		  }
-		else
-			tree->root = e;
-
-		e = p;
-	  }
-
-	adjust_up(tree, e);
-
-	tree->count--;
-}
-
 _NACORE_DEF void *
 nacore_avl_tree_pop(nacore_avl_tree tree, nacore_avl_tree_elem elem)
 {
 	void *ret;
 
-	pop(tree, elem);
+	nacore_avl_tree_elem_pop(tree, elem);
 
 	ret = elem->value;
 	free(elem);
@@ -653,7 +530,7 @@ merge(void *value, void *opaque)
 	elem = (nacore_avl_tree_elem)value;
 	d = (merge_data_t *)opaque;
 
-	insert(d->dest, elem, d->cmp_opaque);
+	nacore_avl_tree_elem_insert(d->dest, elem, d->cmp_opaque);
 }
 
 _NACORE_DEF nacore_avl_tree
@@ -722,6 +599,154 @@ nacore_avl_tree_dump(nacore_avl_tree tree, nacore_to_string_cb to_string_cb,
 	fprintf(stderr, "AVL tree dump end\n");
 }
 
+_NACORE_DEF nacore_avl_tree_elem
+nacore_avl_tree_elem_new(void *value)
+{
+	nacore_avl_tree_elem ret;
+
+	ret = malloc(sizeof(struct _nacore_avl_tree_elem));
+	if (ret == NULL)
+		return NULL;
+
+	ret->parent = NULL;
+	ret->left = NULL;
+	ret->right = NULL;
+	ret->height = 0;
+	ret->value = value;
+
+	return ret;
+}
+
+_NACORE_DEF void
+nacore_avl_tree_elem_free(nacore_avl_tree_elem elem)
+{
+	free(elem);
+}
+
+_NACORE_DEF void
+nacore_avl_tree_elem_insert(nacore_avl_tree tree, nacore_avl_tree_elem elem,
+			    void *cmp_opaque)
+{
+	int side;
+
+	elem->left   = NULL;
+	elem->right  = NULL;
+	elem->height = 1;
+
+	elem->parent = lookup(tree, elem->value, &side, cmp_opaque);
+
+	if (elem->parent == NULL)
+	  {
+		tree->root = elem;
+		tree->count++;
+		return;
+	  }
+
+	if (side == 0)
+		while (elem->parent->left != NULL)
+			elem->parent = elem->parent->left;
+
+	if (side <= 0)
+		elem->parent->left = elem;
+	else
+		elem->parent->right = elem;
+
+	adjust_up(tree, elem);
+
+	tree->count++;
+}
+
+_NACORE_DEF void
+nacore_avl_tree_elem_pop(nacore_avl_tree tree, nacore_avl_tree_elem elem)
+{
+	nacore_avl_tree_elem p, e;
+
+	if ((elem->left == NULL) && (elem->right == NULL))
+	  {
+		if (elem->parent == NULL)
+		  {
+			tree->root = NULL;
+			tree->count--;
+			return;
+		  }
+
+		e = elem->parent;
+
+		if (e->left == elem)
+			e->left = NULL;
+		else
+			e->right = NULL;
+	  }
+	else if ((elem->left != NULL) && (elem->right == NULL))
+	  {
+		if (elem->parent == NULL)
+		  {
+			tree->root = elem->left;
+			elem->left->parent = NULL;
+			tree->count--;
+			return;
+		  }
+
+		e = elem->parent;
+
+		elem->left->parent = e;
+		if (e->left == elem)
+			e->left = elem->left;
+		else
+			e->right = elem->left;
+	  }
+	else if ((elem->left == NULL) && (elem->right != NULL))
+	  {
+		if (elem->parent == NULL)
+		  {
+			tree->root = elem->right;
+			elem->right->parent = NULL;
+			tree->count--;
+			return;
+		  }
+
+		e = elem->parent;
+
+		elem->right->parent = e;
+		if (e->left == elem)
+			e->left = elem->right;
+		else
+			e->right = elem->right;
+	  }
+	else
+	  {
+		for (e = elem->right; e->left != NULL; e = e->left) ;
+		p = e->parent;
+
+		e->left = elem->left;
+		e->left->parent = e;
+		if (elem->right != e)
+		  {
+			p->left = e->right;
+			e->right = elem->right;
+			e->right->parent = e;
+		  }
+		else
+			p = e;
+		e->parent = elem->parent;
+		if (e->parent != NULL)
+		  {
+			if (e->parent->left == elem)
+				e->parent->left = e;
+			else
+				e->parent->right = e;
+		  }
+		else
+			tree->root = e;
+
+		e = p;
+	  }
+
+	adjust_up(tree, e);
+
+	tree->count--;
+}
+
 _NACORE_DEF void *
 nacore_avl_tree_elem_get_value(nacore_avl_tree tree, nacore_avl_tree_elem elem)
 {
@@ -736,6 +761,12 @@ nacore_avl_tree_elem_set_value(nacore_avl_tree tree, nacore_avl_tree_elem elem,
 	void *new_val;
 	size_t size;
 
+	if (tree == NULL)
+	  {
+		elem->value = value;
+		return 0;
+	  }
+
 	new_val = NULL;  /* make gcc happy */
 
 	if (tree->gs_cb != NULL)
@@ -748,7 +779,7 @@ nacore_avl_tree_elem_set_value(nacore_avl_tree tree, nacore_avl_tree_elem elem,
 		memcpy(new_val, value, size);
 	  }
 
-	pop(tree, elem);
+	nacore_avl_tree_elem_pop(tree, elem);
 
 	if (tree->gs_cb == NULL)
 		elem->value = value;
@@ -760,7 +791,7 @@ nacore_avl_tree_elem_set_value(nacore_avl_tree tree, nacore_avl_tree_elem elem,
 		elem->value = new_val;
 	  }
 
-	insert(tree, elem, cmp_opaque);
+	nacore_avl_tree_elem_insert(tree, elem, cmp_opaque);
 
 	return 0;
 }
