@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -122,22 +122,7 @@ nacore_list_prepend(nacore_list list, void *gs_opaque, void *value)
 	if (ret == NULL)
 		return NULL;
 
-	ret->prev = NULL;
-
-	if (list->head == NULL)
-	  {
-		list->head = ret;
-		list->tail = ret;
-		ret->next = NULL;
-	  }
-	else
-	  {
-		ret->next = list->head;
-		list->head->prev = ret;
-		list->head = ret;
-	  }
-
-	list->count++;
+	nacore_list_elem_prepend(list, ret);
 
 	return ret;
 }
@@ -151,22 +136,7 @@ nacore_list_append(nacore_list list, void *gs_opaque, void *value)
 	if (ret == NULL)
 		return NULL;
 
-	ret->next = NULL;
-
-	if (list->tail == NULL)
-	  {
-		list->head = ret;
-		list->tail = ret;
-		ret->prev = NULL;
-	  }
-	else
-	  {
-		ret->prev = list->tail;
-		list->tail->next = ret;
-		list->tail = ret;
-	  }
-
-	list->count++;
+	nacore_list_elem_append(list, ret);
 
 	return ret;
 }
@@ -181,17 +151,7 @@ nacore_list_insert_before(nacore_list list, nacore_list_elem elem,
 	if (ret == NULL)
 		return NULL;
 
-	ret->next = elem;
-
-	ret->prev = elem->prev;
-	elem->prev = ret;
-
-	if (ret->prev == NULL)
-		list->head = ret;
-	else
-		ret->prev->next = ret;
-
-	list->count++;
+	nacore_list_elem_insert_before(list, ret, elem);
 
 	return ret;
 }
@@ -206,17 +166,7 @@ nacore_list_insert_after(nacore_list list, nacore_list_elem elem,
 	if (ret == NULL)
 		return NULL;
 
-	ret->prev = elem;
-
-	ret->next = elem->next;
-	elem->next = ret;
-
-	if (ret->next == NULL)
-		list->tail = ret;
-	else
-		ret->next->prev = ret;
-
-	list->count++;
+	nacore_list_elem_insert_after(list, ret, elem);
 
 	return ret;
 }
@@ -300,20 +250,9 @@ nacore_list_pop(nacore_list list, nacore_list_elem elem)
 {
 	void *ret;
 
-	if (elem->prev != NULL)
-		elem->prev->next = elem->next;
-	else
-		list->head = elem->next;
-
-	if (elem->next != NULL)
-		elem->next->prev = elem->prev;
-	else
-		list->tail = elem->prev;
-
-	list->count--;
+	nacore_list_elem_pop(list, elem);
 
 	ret = elem->value;
-
 	free(elem);
 
 	return ret;
@@ -490,6 +429,120 @@ nacore_list_dump(nacore_list list, nacore_to_string_cb to_string_cb,
 	fprintf(stderr, "List dump end\n");
 }
 
+_NACORE_DEF nacore_list_elem
+nacore_list_elem_new(void *value)
+{
+	nacore_list_elem ret;
+
+	ret = malloc(sizeof(struct _nacore_list_elem));
+	if (ret == NULL)
+		return NULL;
+
+	ret->prev = NULL;
+	ret->next = NULL;
+	ret->value = value;
+
+	return ret;
+}
+
+_NACORE_DEF void
+nacore_list_elem_free(nacore_list_elem elem)
+{
+	free(elem);
+}
+
+_NACORE_DEF void
+nacore_list_elem_prepend(nacore_list list, nacore_list_elem elem)
+{
+	elem->prev = NULL;
+
+	if (list->head == NULL)
+	  {
+		list->head = elem;
+		list->tail = elem;
+		elem->next = NULL;
+	  }
+	else
+	  {
+		elem->next = list->head;
+		list->head->prev = elem;
+		list->head = elem;
+	  }
+
+	list->count++;
+}
+
+_NACORE_DEF void
+nacore_list_elem_append(nacore_list list, nacore_list_elem elem)
+{
+	elem->next = NULL;
+
+	if (list->tail == NULL)
+	  {
+		list->head = elem;
+		list->tail = elem;
+		elem->prev = NULL;
+	  }
+	else
+	  {
+		elem->prev = list->tail;
+		list->tail->next = elem;
+		list->tail = elem;
+	  }
+
+	list->count++;
+}
+
+_NACORE_DEF void
+nacore_list_elem_insert_before(nacore_list list, nacore_list_elem elem,
+			       nacore_list_elem before)
+{
+	elem->next = before;
+
+	elem->prev = before->prev;
+	before->prev = elem;
+
+	if (elem->prev == NULL)
+		list->head = elem;
+	else
+		elem->prev->next = elem;
+
+	list->count++;
+}
+
+_NACORE_DEF void
+nacore_list_elem_insert_after(nacore_list list, nacore_list_elem elem,
+			      nacore_list_elem after)
+{
+	elem->prev = after;
+
+	elem->next = after->next;
+	after->next = elem;
+
+	if (elem->next == NULL)
+		list->tail = elem;
+	else
+		elem->next->prev = elem;
+
+	list->count++;
+}
+
+_NACORE_DEF void
+nacore_list_elem_pop(nacore_list list, nacore_list_elem elem)
+{
+	if (elem->prev != NULL)
+		elem->prev->next = elem->next;
+	else
+		list->head = elem->next;
+
+	if (elem->next != NULL)
+		elem->next->prev = elem->prev;
+	else
+		list->tail = elem->prev;
+
+	list->count--;
+}
+
 _NACORE_DEF void *
 nacore_list_elem_get_value(nacore_list list, nacore_list_elem elem)
 {
@@ -504,6 +557,12 @@ nacore_list_elem_set_value(nacore_list list, nacore_list_elem elem,
 	void *new_val;
 	size_t size;
 
+	if (list == NULL)
+	  {
+		elem->value = value;
+		return 0;
+	  }
+
 	new_val = NULL;  /* make gcc happy */
 
 	if (list->gs_cb != NULL)
