@@ -2,22 +2,15 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
 
-#define _XOPEN_SOURCE 700
+#define _POSIX_C_SOURCE	200809L
 
 #include "internal.h"
 
-#include <pthread.h>
-
-struct _nacore_mutex
-  {
-	pthread_mutex_t mutex;
-  };
-
 _NACORE_DEF nacore_mutex
 nacore_mutex_new()
 {
@@ -25,7 +18,7 @@ nacore_mutex_new()
 	nacore_mutex ret;
 	int err;
 
-	ret = malloc(sizeof(struct _nacore_mutex));
+	ret = malloc(sizeof(pthread_mutex_t));
 	if (ret == NULL)
 	  {
 		errno = ENOMEM;
@@ -40,7 +33,7 @@ nacore_mutex_new()
 	  }
 
 	pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_ERRORCHECK);
-	err = pthread_mutex_init(&ret->mutex, &attr);
+	err = pthread_mutex_init((pthread_mutex_t *)ret, &attr);
 	pthread_mutexattr_destroy(&attr);
 	if (err != 0)
 	  {
@@ -55,7 +48,7 @@ nacore_mutex_new()
 _NACORE_DEF void
 nacore_mutex_free(nacore_mutex mutex)
 {
-	pthread_mutex_destroy(&mutex->mutex);
+	pthread_mutex_destroy((pthread_mutex_t *)mutex);
 
 	free(mutex);
 }
@@ -63,17 +56,17 @@ nacore_mutex_free(nacore_mutex mutex)
 _NACORE_DEF int
 nacore_mutex_lock(nacore_mutex mutex)
 {
-	return pthread_mutex_lock(&mutex->mutex);
+	return pthread_mutex_lock((pthread_mutex_t *)mutex);
 }
 
 _NACORE_DEF int
 nacore_mutex_trylock(nacore_mutex mutex)
 {
-	return pthread_mutex_trylock(&mutex->mutex);
+	return pthread_mutex_trylock((pthread_mutex_t *)mutex);
 }
 
 _NACORE_DEF void
 nacore_mutex_unlock(nacore_mutex mutex)
 {
-	pthread_mutex_unlock(&mutex->mutex);
+	pthread_mutex_unlock((pthread_mutex_t *)mutex);
 }
