@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -109,63 +109,48 @@ nacore_char_utf8_decode(const char *utf8c, uint32_t *cp)
 }
 
 _NACORE_DEF size_t
-nacore_char_utf16le_encode(char *utf16lec, uint32_t cp)
+nacore_char_utf16_encode(uint16_t *utf16c, uint32_t cp)
 {
-	uint8_t *c;
-
 	if ((cp > 0x10ffff) || ((cp >= 0xd800) && (cp <= 0xdfff))
 	    || (cp == 0xfeff) || (cp == 0xfffe))
 		return 0;
 
-	c = (uint8_t *)utf16lec;
-
 	if (cp < 0x10000)
 	  {
-		if (c != NULL)
-		  {
-			c[0] = cp & 0xff;
-			c[1] = (cp >> 8) & 0xff;
-		  }
+		if (utf16c != NULL)
+			*utf16c = cp;
 		return 2;
 	  }
 
-	if (c != NULL)
+	if (utf16c != NULL)
 	  {
 		cp -= 0x10000;
-		c[0] = (cp >> 10) & 0xff;
-		c[1] = 0xd8 | ((cp >> 18) & 0x3);
-		c[2] = cp & 0xff;
-		c[3] = 0xdc | ((cp >> 8) & 0x3);
+		utf16c[0] = 0xd8 | ((cp >> 10) & 0x3ff);
+		utf16c[1] = 0xdc | (cp & 0x3ff);
 	  }
 	return 4;
 }
 
 _NACORE_DEF size_t
-nacore_char_utf16le_decode(const char *utf16lec, uint32_t *cp)
+nacore_char_utf16_decode(const uint16_t *utf16c, uint32_t *cp)
 {
-	const uint8_t *c;
-	uint32_t u;
-
-	c = (const uint8_t *)utf16lec;
-
-	u = c[0] | (c[1] << 8);
-	if ((u == 0xfeff) || (u == 0xfffe))
+	if ((*utf16c == 0xfeff) || (*utf16c == 0xfffe))
 		return 0;
-	if ((u >= 0xd800) && (u <= 0xdbff))
+	if ((*utf16c >= 0xd800) && (*utf16c <= 0xdbff))
 	  {
 		if (cp != NULL)
-			*cp =  0x10000 + (((u & 0x3ff) << 10) | c[2]
-					  | ((c[3] & 0x3) << 8));
+			*cp = 0x10000 + (((utf16c[0] & 0x3ff) << 10)
+					 | (utf16c[1] & 0x3ff));
 		return 4;
 	  }
 
 	if (cp != NULL)
-		*cp = u;
+		*cp = *utf16c;
 	return 2;
 }
 
 _NACORE_DEF size_t
-nacore_string_utf8_to_utf16le_len(const char *str_utf8)
+nacore_string_utf8_to_utf16_len(const char *str_utf8)
 {
 	const char *c8;
 	uint32_t cp;
@@ -180,17 +165,17 @@ nacore_string_utf8_to_utf16le_len(const char *str_utf8)
 			continue;
 		  }
 
-		ret += nacore_char_utf16le_encode(NULL, cp);
+		ret += nacore_char_utf16_encode(NULL, cp);
 	  }
 
 	return ret;
 }
 
 _NACORE_DEF void
-nacore_string_utf8_to_utf16le(char *buf, const char *str_utf8)
+nacore_string_utf8_to_utf16(uint16_t *buf, const char *str_utf8)
 {
 	const char *c8;
-	char *c16;
+	uint16_t *c16;
 	uint32_t cp;
 	size_t s8, s16;
 
@@ -204,41 +189,39 @@ nacore_string_utf8_to_utf16le(char *buf, const char *str_utf8)
 			continue;
 		  }
 
-		s16 = nacore_char_utf16le_encode(c16, cp);
+		s16 = nacore_char_utf16_encode(c16, cp) >> 1;
 	  }
 
-	c16[0] = 0;
-	c16[1] = 0;
+	*c16 = 0;
 }
 
-_NACORE_DEF char *
-nacore_string_utf8_to_utf16le_a(const char *str_utf8)
+_NACORE_DEF uint16_t *
+nacore_string_utf8_to_utf16_a(const char *str_utf8)
 {
-	char *ret;
+	uint16_t *ret;
 	size_t len;
 
-	len = nacore_string_utf8_to_utf16le_len(str_utf8);
+	len = nacore_string_utf8_to_utf16_len(str_utf8);
 
 	ret = malloc(len + 2);
 	if (ret == NULL)
 		return NULL;
 
-	nacore_string_utf8_to_utf16le(ret, str_utf8);
+	nacore_string_utf8_to_utf16(ret, str_utf8);
 
 	return ret;
 }
 
 _NACORE_DEF size_t
-nacore_string_utf16le_to_utf8_len(const char *str_utf16le)
+nacore_string_utf16_to_utf8_len(const uint16_t *str_utf16)
 {
-	const char *c16;
+	const uint16_t *c16;
 	uint32_t cp;
 	size_t s, ret;
 
-	for (c16 = str_utf16le, ret = 0; (c16[0] != 0) || (c16[1] != 0);
-	     c16 += s)
+	for (c16 = str_utf16, ret = 0; *c16 != 0; c16 += s)
 	  {
-		s = nacore_char_utf16le_decode(c16, &cp);
+		s = nacore_char_utf16_decode(c16, &cp) >> 1;
 		if (s == 0)
 		  {
 			s = 2;
@@ -252,17 +235,16 @@ nacore_string_utf16le_to_utf8_len(const char *str_utf16le)
 }
 
 _NACORE_DEF void
-nacore_string_utf16le_to_utf8(char *buf, const char *str_utf16le)
+nacore_string_utf16_to_utf8(char *buf, const uint16_t *str_utf16)
 {
-	const char *c16;
+	const uint16_t *c16;
 	char *c8;
 	uint32_t cp;
 	size_t s8, s16;
 
-	for (c8 = buf, c16 = str_utf16le; (c16[0] != 0) || (c16[1] != 0);
-	     c8 += s8, c16 += s16)
+	for (c8 = buf, c16 = str_utf16; *c16 != 0; c8 += s8, c16 += s16)
 	  {
-		s16 = nacore_char_utf16le_decode(c16, &cp);
+		s16 = nacore_char_utf16_decode(c16, &cp) >> 1;
 		if (s16 == 0)
 		  {
 			s16 = 2;
@@ -277,18 +259,18 @@ nacore_string_utf16le_to_utf8(char *buf, const char *str_utf16le)
 }
 
 _NACORE_DEF char *
-nacore_string_utf16le_to_utf8_a(const char *str_utf16le)
+nacore_string_utf16_to_utf8_a(const uint16_t *str_utf16)
 {
 	char *ret;
 	size_t len;
 
-	len = nacore_string_utf16le_to_utf8_len(str_utf16le);
+	len = nacore_string_utf16_to_utf8_len(str_utf16);
 
 	ret = malloc(len + 1);
 	if (ret == NULL)
 		return NULL;
 
-	nacore_string_utf16le_to_utf8(ret, str_utf16le);
+	nacore_string_utf16_to_utf8(ret, str_utf16);
 
 	return ret;
 }
