@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -14,18 +14,18 @@
 
 #include <windows.h>
 
-static char *
+static uint16_t *
 msg_get(DWORD err)
 {
 	LPTSTR msgbuf;
-	char *ret;
+	uint16_t *ret;
 
 	if (FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER
 			   | FORMAT_MESSAGE_FROM_SYSTEM, NULL, err, 0,
 			   (LPTSTR)&msgbuf, 0, NULL) == 0)
 		return NULL;
 
-	ret = nacore_string_utf16le_to_utf8_a((char *)msgbuf);
+	ret = nacore_string_utf16_to_utf8_a((char *)msgbuf);
 
 	LocalFree(msgbuf);
 	
@@ -37,10 +37,10 @@ nacore_dl_open(const char *filename, nacore_msg_context msg_context,
 	       void *msg_data)
 {
 	HMODULE ret;
-	char *filenamew;
+	uint16_t *filenamew;
 	char *msg;
 
-	filenamew = nacore_string_utf8_to_utf16le_a(filename);
+	filenamew = nacore_string_utf8_to_utf16_a(filename);
 	if (filenamew == NULL)
 	  {
 		nacore_msg_text(msg_context, nacore_msg_severity_err, msg_data,
