@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -19,10 +19,10 @@ nacore_env_get(const char *name)
 {
 	const char buf[32767 * 2];
 	const char *ret;
-	char *namew;
+	uint16_t *namew;
 	DWORD err;
 
-	namew = nacore_string_utf8_to_utf16le_a(name);
+	namew = nacore_string_utf8_to_utf16_a(name);
 	if (namew == NULL)
 	  {
 		errno = ENOMEM;
@@ -38,7 +38,7 @@ nacore_env_get(const char *name)
 		return NULL;
 	  }
 
-	ret = nacore_string_utf16le_to_utf8_a(buf);
+	ret = nacore_string_utf16_to_utf8_a(buf);
 	if (ret == NULL)
 	  {
 		errno = ENOMEM;
