@@ -2,7 +2,7 @@
  * NASPRO - The NASPRO Architecture for Sound Processing
  * Core library
  *
- * Copyright (C) 2007-2011 NASPRO core development team
+ * Copyright (C) 2007-2012 NASPRO core development team
  *
  * See the COPYING file for license conditions.
  */
@@ -27,7 +27,8 @@ _NACORE_DEF nacore_fs_dir
 nacore_fs_dir_open(const char *name)
 {
 	nacore_fs_dir ret;
-	char *namew, *tmp;
+	uint16_t *namew;
+	char *tmp;
 	int errsv;
 
 	ret = malloc(sizeof(struct _nacore_fs_dir));
@@ -45,7 +46,7 @@ nacore_fs_dir_open(const char *name)
 		return NULL;
 	  }
 
-	namew = nacore_string_utf8_to_utf16le_a(tmp);
+	namew = nacore_string_utf8_to_utf16_a(tmp);
 	free(tmp);
 	if (namew == NULL)
 	  {
@@ -132,8 +133,8 @@ nacore_fs_dir_get_next_entry(nacore_fs_dir dir)
 
 		dir->first = 0;
 
-		ret = nacore_string_utf16le_to_utf8_a(
-				(const char *)dir->fdata.cFileName);
+		ret = nacore_string_utf16_to_utf8_a(
+				(const uint16_t *)dir->fdata.cFileName);
 		if (ret == NULL)
 		  {
 			errno = ENOMEM;
